@@ -10,7 +10,7 @@ import gobject
 from mopidy import config, ext
 
 
-__version__ = '1.0.0'
+__version__ = '1.1.0'
 
 
 class Extension(ext.Extension):
@@ -22,7 +22,7 @@ class Extension(ext.Extension):
         conf_file = os.path.join(os.path.dirname(__file__), 'ext.conf')
         return config.read(conf_file)
 
-    def register_gstreamer_elements(self):
+    def setup(self, registry):
         from .mixer import NadMixer
         gobject.type_register(NadMixer)
         gst.element_register(NadMixer, 'nadmixer', gst.RANK_MARGINAL)
